@@ -1,7 +1,3 @@
-usethis::use_package("shiny")
-usethis::use_package("shinyjs")
-usethis::use_package("RColorBrewer")
-
 #' Plot spectra
 #'
 #' \code{plot} plots spectra.
@@ -22,7 +18,7 @@ usethis::use_package("RColorBrewer")
 #'
 #' @examples
 #' library(spectrolab)
-#' spec  = as.spectra(spec_matrix_example, name_idx = 1)
+#' spec  = as_spectra(spec_matrix_example, name_idx = 1)
 #' plot(spec, lwd = 1.2)
 plot.spectra = function(x,
                         ylab = "value",
@@ -72,7 +68,7 @@ plot.spectra = function(x,
 #'
 #' @examples
 #' library(spectrolab)
-#' spec  = as.spectra(spec_matrix_example, name_idx = 1)
+#' spec  = as_spectra(spec_matrix_example, name_idx = 1)
 #' plot_quantile(spec, total_prob = 0.5)
 plot_quantile = function(spec,
                          total_prob = 0.95,
@@ -167,7 +163,7 @@ default_spec_regions = function(){
 #'
 #' @examples
 #' library(spectrolab)
-#' spec = as.spectra(spec_matrix_example, name_idx = 1)
+#' spec = as_spectra(spec_matrix_example, name_idx = 1)
 #' plot_regions(spec, default_spec_regions())
 #' plot(spec, add = TRUE)
 #'
@@ -260,7 +256,7 @@ plot_regions = function(spec,
 #' @examples
 #' \dontrun{
 #' # Create a spectra object
-#' spec = as.spectra(spec_matrix_example, name_idx = 1)
+#' spec = as_spectra(spec_matrix_example, name_idx = 1)
 #'
 #' # Start interactive plot
 #' plot_interactive(spec)
