@@ -86,7 +86,7 @@ apply_by_band.spectra = function(x, fun, na.rm = TRUE, keep_txt_meta = TRUE, nam
 #'
 #' @param x spectra object
 #' @param by vector of factors to guide the aggregation
-#' @param FUN function to be applied to refl (and meta if FUN_meta is NULL)
+#' @param FUN function to be applied to value (and meta if FUN_meta is NULL)
 #' @param FUN_meta function to be applied to metadata. If NULL (default), same
 #'        FUN applied to value is used.
 #' @param ... extra args to FUN
@@ -431,7 +431,7 @@ smooth.default = function(x, ...){
 #' @param x spectra object. bands must be strictly increasing
 #' @param method Choose smoothing method: "spline" (default) or "moving_average"
 #' @param ... additional parameters passed to \code{smooth.spline} or parameters
-#'            `n` and `save_wvls_to_meta` for the moving average smoothing.
+#'            `n` and `save_bands_to_meta` for the moving average smoothing.
 #' @return a spectra object of with smoothed spectra
 #'
 #' @author Jose Eduardo Meireles
@@ -518,12 +518,12 @@ smooth_spline = function(x, parallel = TRUE, ...) {
 #'
 #' @param x spectra object
 #' @param n = NULL
-#' @param save_wvls_to_meta boolean. keep lost ends of original wvls in metadata
+#' @param save_bands_to_meta boolean. keep lost ends of original wvls in metadata
 #' @return spectra object
 #'
 #' @author Jose Eduardo Meireles
 #' @export
-smooth_moving_avg = function(x, n = NULL, save_wvls_to_meta = TRUE){
+smooth_moving_avg = function(x, n = NULL, save_bands_to_meta = TRUE){
     if( !is_spectra(x) ){
         stop("Object must be of class spectra")
     }
@@ -555,7 +555,7 @@ smooth_moving_avg = function(x, n = NULL, save_wvls_to_meta = TRUE){
 
         message("Smoothing transformed some values into NAs and those bands were removed")
 
-        if(save_wvls_to_meta){
+        if(save_bands_to_meta){
             message("However, the original values for those bands were kept as metadata")
 
             meta(x) = matrix(r[ , w],
@@ -579,7 +579,7 @@ smooth_moving_avg = function(x, n = NULL, save_wvls_to_meta = TRUE){
 #' \code{resample} doesn't predict values for bands outside of the original range.
 #'
 #' @param x spectra object. bands must be strictly increasing
-#' @param new_wvls numeric vector of bands to sample from spectra
+#' @param new_bands numeric vector of bands to sample from spectra
 #' @param ... additional parameters passed to the \code{smooth.spline} function.
 #' @return spectra object with resampled spectra
 #'
@@ -591,22 +591,22 @@ smooth_moving_avg = function(x, n = NULL, save_wvls_to_meta = TRUE){
 #' @examples
 #' library(spectrolab)
 #' spec = as_spectra(spec_matrix_example, name_idx = 1)
-#' spec = resample(spec, new_wvls = seq(400, 2400, 0.5), parallel = FALSE)
-resample = function(x, new_wvls, ...) {
+#' spec = resample(spec, new_bands = seq(400, 2400, 0.5), parallel = FALSE)
+resample = function(x, new_bands, ...) {
     UseMethod("resample")
 }
 
 
 #' @describeIn resample Resample spectra
 #' @export
-resample.spectra = function(x, new_wvls, ...) {
+resample.spectra = function(x, new_bands, ...) {
 
     w = bands(x)
 
-    ## Simply subset the current spectra if all new_wvls are a in the set of
+    ## Simply subset the current spectra if all new_bands are a in the set of
     ## current bands
-    if(all(new_wvls %in% w)){
-        return(x[ , new_wvls ])
+    if(all(new_bands %in% w)){
+        return(x[ , new_bands ])
     }
 
     ## Enforce increasing bands in spectra object
@@ -617,7 +617,7 @@ resample.spectra = function(x, new_wvls, ...) {
     ## Do not predict points outside the original band range
     r = range(bands(x))
 
-    if(min(new_wvls) < r[1] || max(new_wvls) > r[2]){
+    if(min(new_bands) < r[1] || max(new_bands) > r[2]){
         stop("New band values must be within the data's range: ", r[1], " to ", r[2])
     }
 
@@ -625,12 +625,12 @@ resample.spectra = function(x, new_wvls, ...) {
     message("Using spline to predict value at new bands...")
     s = smooth_spline(x, ...)
     f = function(o, p){ stats::predict(o, p)[["y"]] }
-    g = lapply(X = s, FUN = f, p = new_wvls)
+    g = lapply(X = s, FUN = f, p = new_bands)
     message("Beware the spectra are now partially smoothed.")
 
     ## Construct new spectra object and return
     spectra(value = do.call(rbind, g),
-            bands = new_wvls,
+            bands = new_bands,
             names = names(x),
             meta  = meta(x))
 
